@@ -1,5 +1,4 @@
 import {
-  GET_ALL_OS,
   SET_OPERATING_SYSTEMS,
 } from '_/constants'
 
@@ -12,7 +11,3 @@ export function setOperatingSystems (operatingSystems) {
     payload: operatingSystems,
   }
 }
-
-export function getAllOperatingSystems () {
-  return { type: GET_ALL_OS }
-}
