@@ -3,7 +3,7 @@ import PropTypes from 'prop-types'
 
 const ErrorAlert = ({ id, message, children }) => {
   return (
-    <div className='alert alert-danger'>
+    <div className='alert error-alert alert-danger'>
       <span className='pficon pficon-error-circle-o' />
       <span id={id}>
         {message && (<strong>{message}</strong>)}
