@@ -57,7 +57,7 @@ class IconUpload extends React.Component {
       : null
 
     return (
-      <React.Fragment>
+      <>
         <dt>
           <FieldHelp content={msg.customIcon()} text={msg.icon()} />
         </dt>
@@ -68,7 +68,7 @@ class IconUpload extends React.Component {
               id='uploadIconInput'
               type='file'
               accept='image/*'
-              className={style['hide']}
+              className={style.hide}
               value={''}
               onChange={this.handleIconChange}
             />
@@ -77,12 +77,13 @@ class IconUpload extends React.Component {
             id='button-default-icon'
             className={`btn btn-default ${style['upload-button']}`}
             type='button'
-            onClick={() => { this.props.onIconChange() }} >
+            onClick={() => { this.props.onIconChange() }}
+          >
             {msg.defaultButton()}
           </button>
           {iconError}
         </dd>
-      </React.Fragment>
+      </>
     )
   }
 }
