@@ -16,15 +16,15 @@ const FieldRow = ({ label, children, id, tooltip, tooltipPosition, validationSta
   >
     <Col cols={5} className={style['col-label']}>
       <ControlLabel>{label}</ControlLabel>
-      {tooltip &&
-        <span className={style['tooltip']}>
+      {tooltip && (
+        <span className={style.tooltip}>
           <InfoTooltip
             id={`${id}-tooltip`}
             tooltip={tooltip}
             placement={tooltipPosition}
           />
         </span>
-      }
+      )}
     </Col>
     <Col cols={7} className={style['col-data']} id={id}>{children}</Col>
   </FormGroup>
@@ -32,7 +32,7 @@ const FieldRow = ({ label, children, id, tooltip, tooltipPosition, validationSta
 FieldRow.propTypes = {
   id: PropTypes.string.isRequired,
   label: PropTypes.string.isRequired,
-  tooltip: PropTypes.oneOfType([ Tooltip.propTypes.tooltip ]),
+  tooltip: PropTypes.oneOfType([Tooltip.propTypes.tooltip]),
   children: PropTypes.node.isRequired,
   tooltipPosition: Tooltip.propTypes.placement,
   validationState: FormGroup.propTypes.validationState,
