@@ -5,6 +5,7 @@ import type {
   NicType,
   SnapshotType,
   VmType,
+  ActionResponseType,
 } from './types'
 
 import Selectors from '../selectors'
@@ -31,33 +32,6 @@ const OvirtApi = {
   addHttpListener: transportAddHttpListener,
   updateLocale: transportUpdateLocale,
 
-  //
-  //
-  // ---- Data transform functions (API -> internal, internal -> API)
-  //
-  //
-  poolToInternal: Transforms.Pool.toInternal,
-
-  diskToInternal: Transforms.DiskAttachment.toInternal,
-
-  nicToInternal: Transforms.Nic.toInternal,
-
-  sessionsToInternal: Transforms.VmSessions.toInternal,
-
-  iconToInternal: Transforms.Icon.toInternal,
-
-  cdRomToInternal: Transforms.CdRom.toInternal,
-
-  SSHKeyToInternal: Transforms.SSHKey.toInternal,
-
-  consolesToInternal: Transforms.VmConsoles.toInternal,
-
-  snapshotToInternal: Transforms.Snapshot.toInternal,
-
-  permissionsToInternal: Transforms.Permissions.toInternal,
-
-  eventToInternal: Transforms.Event.toInternal,
-
   //
   //
   // ---- API interaction functions
@@ -120,17 +94,10 @@ const OvirtApi = {
     return httpGet({ url })
   },
 
-  // TODO: Convert to use frontend based role to permission mapping
-  getDiskPermissions ({ id }: { id: string }): Promise<Object> {
-    assertLogin({ methodName: 'getDiskPermissions' })
-    const url = `${AppConfiguration.applicationContext}/api/disks/${id}/permissions?follow=role.permits`
-    return httpGet({ url, custHeaders: { Filter: true } })
-  },
-  // TODO: Convert to use frontend based role to permission mapping
-  getVmPermissions ({ vmId }: VmIdType): Promise<Object> {
-    assertLogin({ methodName: 'getVmPermissions' })
-    const url = `${AppConfiguration.applicationContext}/api/vms/${vmId}/permissions?follow=role.permits`
-    return httpGet({ url, custHeaders: { Filter: true } })
+  getJob ({ jobId }: { jobId: string }): Promise<Object> {
+    assertLogin({ methodName: 'getJob' })
+    const url = `${AppConfiguration.applicationContext}/api/jobs/${jobId}`
+    return httpGet({ url })
   },
 
   // ---- VM fetching
@@ -200,7 +167,7 @@ const OvirtApi = {
       input,
     })
   },
-  remove ({ vmId, preserveDisks }: { vmId: string, preserveDisks: boolean }): Promise<Object> {
+  remove ({ vmId, preserveDisks }: { vmId: string, preserveDisks: boolean }): Promise<ActionResponseType> {
     assertLogin({ methodName: 'remove' })
     let url = `${AppConfiguration.applicationContext}/api/vms/${vmId}`
     if (preserveDisks) {
@@ -209,35 +176,33 @@ const OvirtApi = {
     return httpDelete({
       url,
       custHeaders: {
-        'Accept': 'application/json',
+        Accept: 'application/json',
       },
     })
   },
-  shutdown ({ vmId, force }: { vmId: string, force: boolean }): Promise<Object> {
+  shutdown ({ vmId, force }: { vmId: string, force: boolean }): Promise<ActionResponseType> {
     assertLogin({ methodName: 'shutdown' })
-    let restMethod = 'shutdown'
-    if (force) {
-      restMethod = 'stop'
-    }
+    const restMethod = force ? 'stop' : 'shutdown'
     return httpPost({
       url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/${restMethod}`,
       input: '{}',
     })
   },
-  start ({ vmId }: VmIdType): Promise<Object> {
+  start ({ vmId }: VmIdType): Promise<ActionResponseType> {
     assertLogin({ methodName: 'start' })
     return httpPost({
       url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/start`,
-      input: '{}' })
+      input: '{}',
+    })
   },
-  suspend ({ vmId }: VmIdType): Promise<Object> {
+  suspend ({ vmId }: VmIdType): Promise<ActionResponseType> {
     assertLogin({ methodName: 'suspend' })
     return httpPost({
       url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/suspend`,
       input: '{}',
     })
   },
-  restart ({ vmId }: VmIdType): Promise<Object> { // 'force' is not exposed by oVirt API
+  restart ({ vmId }: VmIdType): Promise<ActionResponseType> {
     assertLogin({ methodName: 'restart' })
     return httpPost({
       url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/reboot`,
@@ -249,7 +214,6 @@ const OvirtApi = {
   addNewSnapshot ({ vmId, snapshot }: { vmId: string, snapshot: SnapshotType }): Promise<Object> {
     assertLogin({ methodName: 'addNewSnapshot' })
     const input = JSON.stringify(Transforms.Snapshot.toApi({ snapshot }))
-    console.log(`OvirtApi.addNewSnapshot(): ${input}`)
     return httpPost({
       url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/snapshots`,
       input,
@@ -286,13 +250,13 @@ const OvirtApi = {
     return httpGet({ url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/snapshots` })
   },
 
-  diskattachment ({ vmId, attachmentId }: { vmId: string, attachmentId: string}): Promise<Object> {
-    assertLogin({ methodName: 'diskattachment' })
-    return httpGet({ url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/diskattachments/${attachmentId}?follow=disk` })
-  },
   diskattachments ({ vmId }: VmIdType): Promise<Object> {
     assertLogin({ methodName: 'diskattachments' })
-    return httpGet({ url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/diskattachments` })
+    return httpGet({ url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/diskattachments?follow=disk.permissions` })
+  },
+  diskattachment ({ vmId, attachmentId }: { vmId: string, attachmentId: string}): Promise<Object> {
+    assertLogin({ methodName: 'diskattachment' })
+    return httpGet({ url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/diskattachments/${attachmentId}?follow=disk.permissions` })
   },
   disk ({ diskId }: { diskId: string }): Promise<Object> {
     assertLogin({ methodName: 'disk' })
@@ -303,7 +267,8 @@ const OvirtApi = {
     assertLogin({ methodName: 'console' })
     return httpGet({
       url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/graphicsconsoles/${consoleId}`,
-      custHeaders: { Accept: 'application/x-virt-viewer', Filter: Selectors.getFilter() } })
+      custHeaders: { Accept: 'application/x-virt-viewer', Filter: Selectors.getFilter() },
+    })
   },
 
   consoleProxyTicket ({ vmId, consoleId }: { vmId: string, consoleId: string }): Promise<Object> {
@@ -443,7 +408,7 @@ const OvirtApi = {
     return httpGet({
       url: `${AppConfiguration.applicationContext}/services/files/usbfilter.txt`,
       custHeaders: {
-        'Accept': 'text/plain',
+        Accept: 'text/plain',
       },
     })
   },
