@@ -1,6 +1,5 @@
 // @flow
-import Selectors from '_/selectors'
-import type { ClusterType, PermissionType, VnicProfileType } from '_/ovirtapi/types'
+import type { ClusterType, VnicProfileType } from '_/ovirtapi/types'
 
 function checkUserPermit (permit: string | Array<string>, permits: Set<string>): boolean {
   if (Array.isArray(permit)) {
@@ -40,7 +39,7 @@ export function canUserManipulateSnapshots (permits: Set<string>): boolean {
 }
 
 export function canUserUseStorageDomain (permits: Set<string>): boolean {
-  return checkUserPermit([ 'create_disk', 'attach_disk_profile' ], permits)
+  return checkUserPermit(['create_disk', 'attach_disk_profile'], permits)
 }
 
 export function canUserEditVmStorage (permits: Set<string>): boolean {
@@ -68,21 +67,3 @@ export function canUserUseAnyVnicProfile (vnicProfiles: Array<VnicProfileType>,
     vnicProfile.get('canUserUseProfile') && vnicProfile.getIn(['network', 'dataCenterId']) === dataCenterId
   ) !== undefined
 }
-
-export function getUserPermits (permissions: Array<PermissionType>): Set<string> {
-  const userFilter = Selectors.getFilter()
-  const userGroups = Selectors.getUserGroups()
-  const userId = Selectors.getUserId()
-
-  const permits = new Set()
-  permissions.forEach((role) => {
-    if (userFilter ||
-      (
-        (role.groupId && userGroups.includes(role.groupId)) ||
-        (role.userId && role.userId === userId)
-      )) {
-      role.permits.map((permit) => permit.name).forEach((permit) => permits.add(permit))
-    }
-  })
-  return permits
-}
